## Lua控制流程语句

### 1. 条件语句

条件语句用于根据不同的条件执行不同的代码块。Lua中的条件语句包括`if`语句和`if-else`语句。

#### 1.1 `if`语句

`if`语句用于在满足条件时执行一段代码块。

```lua
if condition then
    -- code block
end
```

案例：

```lua
local num = 10

if num > 0 then
    print("The number is positive")
end
```

讲解：在上面的例子中，如果`num`大于0，则会打印出"The number is positive"。

#### 1.2 `if-else`语句

`if-else`语句用于在满足条件时执行一段代码块，否则执行另一段代码块。

```lua
if condition then
    -- code block 1
else
    -- code block 2
end
```

案例：

```lua
local num = 10

if num > 0 then
    print("The number is positive")
else
    print("The number is non-positive")
end
```

讲解：在上面的例子中，如果`num`大于0，则会打印出"The number is positive"；否则，会打印出"The number is non-positive"。

### 2. 循环语句

循环语句用于重复执行一段代码块。Lua中的循环语句包括`while`循环和`for`循环。

#### 2.1 `while`循环

`while`循环用于在满足条件时重复执行一段代码块。

```lua
while condition do
    -- code block
end
```

案例：

```lua
local i = 1

while i <= 5 do
    print(i)
    i = i + 1
end
```

讲解：在上面的例子中，`i`从1开始，每次循环打印出`i`的值，并将`i`加1，直到`i`大于5时停止循环。

#### 2.2 `for`循环

`for`循环用于在指定范围内重复执行一段代码块。

```lua
for variable = start, end, step do
    -- code block
end
```

案例：

```lua
for i = 1, 5, 1 do
    print(i)
end
```

讲解：在上面的例子中，`i`从1开始，每次循环打印出`i`的值，直到`i`等于5时停止循环。

### 3. 跳转语句

跳转语句用于改变程序的执行顺序。Lua中的跳转语句包括`break`语句和`goto`语句。

#### 3.1 `break`语句

`break`语句用于跳出当前循环。

```lua
while condition do
    -- code block
    if condition then
        break
    end
end
```

案例：

```lua
local i = 1

while i <= 5 do
    print(i)
    if i == 3 then
        break
    end
    i = i + 1
end
```

讲解：在上面的例子中，当`i`等于3时，执行`break`语句跳出循环。

#### 3.2 `goto`语句

`goto`语句用于无条件地跳转到指定的标签处。

```lua
::label::
-- code block

goto label
```

案例：

```lua
local i = 1

::loop::
print(i)
if i < 5 then
    i = i + 1
    goto loop
end
```

讲解：在上面的例子中，使用`goto`语句将程序跳转到标签`loop`处，实现循环打印`i`的值，直到`i`等于5时停止循环。

### 总结

通过本教案的学习，您应该对Lua的控制流程语句有了更深入的了解。条件语句可以根据不同的条件执行不同的代码块，循环语句可以重复执行一段代码块，跳转语句可以改变程序的执行顺序。这些控制流程语句是编程中非常重要的基础知识，希望您能够通过实践和练习进一步巩固和应用。