## 循环控制

在 Lua 编程中，`break` 和 `continue` 是两种常用的循环控制语句，用于控制循环结构的执行流程。

### 1. `break` 语句

`break` 语句通常用于循环结构内部，用于终止循环并跳出循环体。当满足某个条件时，你可以使用 `break` 语句提前结束循环，即使循环条件仍然为真。

以下是一个示例，展示了如何使用 `break` 语句提前结束 `for` 循环：

```lua
for i = 1, 5 do
    if i == 3 then
        break -- 当 i 等于 3 时终止循环
    end
    print(i)
end
```

输出：

```
1
2
```

在这个示例中，当 `i` 的值等于 3 时，`break` 被执行，导致循环终止。

除了在循环结构内使用，`break` 语句还可以在 `repeat-until` 循环和 `while` 循环中使用。

### 2. `continue` 语句

`continue` 语句通常也用于循环结构内部，用于跳过当前迭代并继续执行下一次迭代。当某个条件满足时，你可以使用 `continue` 语句跳过当前迭代，直接进入下一次迭代。

以下是一个示例，展示了如何使用 `continue` 语句跳过 `for` 循环中的一个迭代：

```lua
for i = 1, 5 do
    if i == 3 then
        goto continue -- 当 i 等于 3 时跳过当前迭代
    end
    print(i)
    ::continue::
end
```

输出：

```
1
2
4
5
```

在这个示例中，当 `i` 的值等于 3 时，`goto` 语句会跳转到 `continue` 标签处，从而跳过当前迭代并进入下一次迭代。

除了使用 `goto` 语句外，你还可以使用条件语句或其他循环控制语句来实现类似的效果。

### 3. 区别与用法

- `break` 用于终止循环结构，跳出循环体，而 `continue` 用于跳过当前迭代，直接进入下一次迭代。
- `break` 只能用于循环结构内部，而 `continue` 也只能用于循环结构内部。
- `break` 通常与条件语句结合使用来提前结束循环，而 `continue` 通常与条件语句结合使用来跳过特定的迭代。

### 4. 注意事项

在使用 `break` 和 `continue` 语句时，需要注意以下事项：

- 在循环结构中，你可以使用标签（label）和 `goto` 语句来实现复杂的循环控制逻辑。
- 在循环结构中，`break` 和 `continue` 语句只能用于最内层的循环结构中，不能用于外层循环结构。
- 在使用 `continue` 语句时，你需要注意不要进入死循环，否则程序会一直执行下去。



好好学习，天天向上~