## 条件语句

在 Lua 编程中，`if-else` 和 `switch-case` 是两种常用的条件语句，用于根据条件执行不同的代码分支。

### 1. `if-else` 语句

`if-else` 语句用于执行条件分支。它根据给定的条件来判断执行哪个代码块。

以下是一个示例，展示了如何使用 `if-else` 语句：

```lua
local num = 10

if num > 0 then
    print("Number is positive")
elseif num < 0 then
    print("Number is negative")
else
    print("Number is zero")
end
```

输出：

```
Number is positive
```

在这个示例中，我们使用 `if-else` 语句来检查变量 `num` 的值。如果 `num` 大于 0，则打印 "Number is positive"；如果 `num` 小于 0，则打印 "Number is negative"；否则打印 "Number is zero"。

你可以根据需要添加多个 `elseif` 分支，并且 `else` 分支是可选的。

### 2. `switch-case` 语句

Lua 并没有内置的 `switch-case` 语句，但你可以通过使用表（table）和函数来模拟实现类似的功能。

以下是一个示例，展示了如何使用表和函数实现 `switch-case` 语句：

```lua
local num = 2

local cases = {
    [1] = function()
        print("Number is 1")
    end,
    [2] = function()
        print("Number is 2")
    end,
    [3] = function()
        print("Number is 3")
    end,
    default = function()
        print("Number is not 1, 2, or 3")
    end
}

if cases[num] then
    cases[num]()
else
    cases.default()
end
```

输出：

```
Number is 2
```

在这个示例中，我们首先创建了一个表 `cases`，其中包含了不同的数字对应的函数。然后，我们根据变量 `num` 的值来执行相应的函数。如果 `num` 在表 `cases` 中存在对应的函数，则执行该函数；否则执行默认的函数 `default`。

你可以根据需要添加更多的分支，并在 `default` 函数中处理未匹配到的情况。

### 3. 区别与用法

- `if-else` 语句适用于判断单个条件，并根据条件执行相应的代码块。
- `switch-case` 语句适用于根据不同的值执行不同的代码块。在 Lua 中，你可以通过使用表和函数来模拟实现类似的功能。

### 4. 注意事项

在使用条件语句时，需要注意以下事项：

- 在 `if-else` 语句中，条件是一个表达式，它的值可以是布尔型或其他可转换为布尔型的值。
- 在 `switch-case` 语句模拟中，你需要预先定义好不同值对应的函数，并在代码中根据变量值来执行相应的函数。