# Lua 函数教程

在 Lua 中，函数是一种非常重要的编程元素，它可以帮助你组织代码、实现特定功能并提高代码的复用性。本教程将介绍 Lua 中函数的各种用法。


### 基本函数定义和调用
在 Lua 中，你可以使用 `function` 关键字来定义一个函数。以下是一个基本的函数定义和调用示例：
```lua
-- 函数定义
function greet()
    print("Hello, World!")
end

-- 函数调用
greet()
```
在这个示例中，我们定义了一个名为 `greet` 的函数，它打印出 "Hello, World!"。通过调用 `greet()`，函数就会执行。

### 函数参数和返回值
Lua 函数可以接受参数，并且可以返回一个或多个值。以下是一个带有参数和返回值的函数示例：
```lua
-- 函数定义
function add(a, b)
    local result = a + b
    return result
end

-- 函数调用
local sum = add(2, 3)
print(sum)
```
在这个示例中，`add` 函数接受两个参数 `a` 和 `b`，并返回它们的和。通过调用 `add(2, 3)`，将返回结果存储在 `sum` 变量中，并使用 `print` 函数输出。

### 多个返回值
Lua 中的函数可以返回一个或多个值。以下是一个多个返回值的函数示例：
```lua
-- 函数定义
function swap(a, b)
    return b, a
end

-- 函数调用
local x, y = swap(1, 2)
print(x, y)
```
在这个示例中，`swap` 函数接受两个参数 `a` 和 `b`，并返回它们的值交换后的结果。通过调用 `swap(1, 2)`，将返回值存储在 `x` 和 `y` 变量中，并使用 `print` 函数输出。

## 变长参数函数
有时候你可能需要编写一个可以接受任意数量参数的函数。Lua 中可以使用 `...` 来实现这个功能，以下是一个变长参数函数的示例：
```lua
-- 函数定义
function sum(...)
    local result = 0
    for _, v in ipairs({...}) do
        result = result + v
    end
    return result
end

-- 函数调用
local total = sum(1, 2, 3, 4)
print(total)
```
在这个示例中，`sum` 函数可以接受任意数量的参数，通过遍历 `...` 参数列表来计算它们的总和。通过调用 `sum(1, 2, 3, 4)`，将返回结果存储在 `total` 变量中，并使用 `print` 函数输出。

## 匿名函数
Lua 中还支持匿名函数，它们也称为闭包函数。以下是一个匿名函数示例：
```lua
-- 匿名函数定义
local greet = function(name)
    print("Hello, " .. name .. "!")
end

-- 函数调用
greet("Lua")
```
在这个示例中，我们使用 `local` 关键字定义了一个匿名函数，并将其存储在变量 `greet` 中。通过调用 `greet("Lua")`，函数就会执行。

## 总结
本教程介绍了 Lua 中函数的基本概念，包括函数定义和调用、函数参数和返回值、多个返回值、变长参数函数和匿名函数等。希望这些示例能帮助你更好地理解 Lua 中函数的用法。