# Lua 表操作教程

在 Lua 中，表（table）是一种强大的数据结构，它可以用来表示数组、集合、映射等多种数据结构。本教程将详细介绍 Lua 中的表操作，包括创建和访问表、添加、删除和修改表项，以及遍历表。

## 创建和访问表
在 Lua 中，你可以使用花括号 `{}` 来创建一个表，并使用键值对来初始化表的内容。以下是一个创建和访问表的示例：
```lua
-- 创建表
local person = {name = "Alice", age = 25, gender = "female"}

-- 访问表
print(person.name)   -- 输出：Alice
print(person.age)    -- 输出：25
print(person.gender) -- 输出：female
```

在上面的示例中，我们创建了一个名为 `person` 的表，并使用键值对来初始化表的内容。你可以使用键来访问表中的值。

## 添加、删除和修改表项
### 添加表项
你可以通过简单地赋值来向表中添加新的表项。以下是一个添加表项的示例：
```lua
local person = {name = "Alice", age = 25, gender = "female"}
person.email = "alice@example.com"
print(person.email)  -- 输出：alice@example.com
```

### 删除表项
要删除表中的某个表项，你可以将其值设为 `nil`。以下是一个删除表项的示例：
```lua
local person = {name = "Alice", age = 25, gender = "female", email = "alice@example.com"}
person.email = nil
print(person.email)  -- 输出：nil
```

### 修改表项
通过简单地赋值，你可以修改表中已有表项的值。以下是一个修改表项的示例：
```lua
local person = {name = "Alice", age = 25, gender = "female"}
person.age = 26
print(person.age)  -- 输出：26
```

## 遍历表
在 Lua 中，你可以使用 `pairs()` 函数来遍历表中的键值对。以下是一个遍历表的示例：
```lua
local person = {name = "Alice", age = 25, gender = "female", email = "alice@example.com"}
for key, value in pairs(person) do
    print(key, value)
end
```
输出：
```
name    Alice
age     25
gender  female
email   alice@example.com
```

除了使用 `pairs()` 函数，你还可以使用 `ipairs()` 函数来遍历表中的数组部分（即从 1 开始的连续整数索引）。这两个函数提供了遍历表的灵活方式，使你能够轻松地处理不同类型的表数据。

## 总结
本教程介绍了 Lua 中的表操作，包括创建和访问表、添加、删除和修改表项，以及遍历表。希望这些示例能帮助你更好地理解 Lua 中的表操作。